Index: FL/Fl.H
===================================================================
--- FL/Fl.H	(revision 10216)
+++ FL/Fl.H	(working copy)
@@ -1145,7 +1145,12 @@
   /** milli seconds sleep */
   static void msleep(unsigned long milliseconds);
   /** microseconds sleep */
+#if defined(_MSC_VER) && (_MSC_VER <= 1300)		/* VS7 and older */
+  static void usleep(unsigned __int64 microseconds);	/* VS7 doesn't like 'long long' */
+#else
   static void usleep(unsigned long long microseconds);
+#endif
+
   
   /**
     The thread_message() method returns the last message
Index: src/Fl_sleep.cxx
===================================================================
--- src/Fl_sleep.cxx	(revision 10216)
+++ src/Fl_sleep.cxx	(working copy)
@@ -32,7 +32,11 @@
 /** Make the current thread sleep for n seconds, support decimals ... */
 void Fl::sleep(double seconds)
 {
+#if defined(_MSC_VER) && (_MSC_VER <= 1300)		/* VS7 and older */
+  Fl::usleep((unsigned __int64) (seconds*1000000));
+#else
   Fl::usleep((unsigned long long) (seconds*1000000));
+#endif
 }
 
 /** Make the current thread to sleep for n milliseconds */
@@ -46,9 +50,20 @@
 }
 
 /** Make the current thread to sleep for n microseconds */
-void Fl::usleep(unsigned long long microseconds) 
-// unsigned long long more should be more portable than int64_t before c++ 2011 ...
-{
+// unsigned long long should be more portable than int64_t before c++ 2011
+//                                          -- fabien 05/20/2014
+//
+// Hmm, 'long long' considered "illegal" in VS7 and VS6,
+// and CreateWaitableTimer() is not available.
+//                                          -- erco 07/02/2014
+//
+#if defined(_MSC_VER) && (_MSC_VER <= 1300)		/* VS7 and older */
+void Fl::usleep(unsigned __int64 usecs) {
+  DWORD msec = (usecs < 1000 && usecs > 0) ? 1 : (usecs / 1000);
+  ::Sleep(msec);	// HACK: CreatWaitableTimer() not in VS7 or less
+}
+#else
+void Fl::usleep(unsigned long long microseconds) {
 #ifdef WIN32
   HANDLE timer; 
   LARGE_INTEGER reltime; 
@@ -62,6 +77,7 @@
   ::usleep((useconds_t) microseconds);
 #endif
 }
+#endif
 
 //
 // End of "$Id$".
